@@ -1,7 +1,7 @@
 
 import os
 import collections
-import random
+import copy
 import math
 import warnings
 import psutil
@@ -105,7 +105,7 @@ def shuffle_in_chunks(data_length, chunk_size):
         true_chunk_size = min(chunk_size, data_length - chunk_size * chunk_ind)
         values = [-1] * true_chunk_size
         
-        # Generate random list of indices
+        # Generate random list of indexes
         lower_bound_list = np.array(range(j, j + true_chunk_size))
         random_list = rng.integers(lower_bound_list, data_length)
 
@@ -204,7 +204,7 @@ def generate_pool(max_pool_size=None, data_size=None, cols=None):
     Generate a multiprocessing pool to allocate functions too
 
     :param max_pool_size: Max number of processes assigned to the pool
-    :type max_pool_size: int
+    :type max_pool_size: Union[int, None]
     :param data_size: size of the dataset
     :type data_size: int
     :param cols: columns of the dataset
@@ -245,3 +245,33 @@ def overlap(x1, x2, y1, y2):
             (y1 <= x2 <= y2) or
             (x1 <= y1 <= x2) or
             (x1 <= y2 <= x2))
+
+def add_nested_dictionaries(first_dict, second_dict):
+    """
+    Merges two dictionaries together and adds values together
+
+    :param first_dict: dictionary to be merged
+    :type first_dict: dict
+    :param second_dict: dictionary to be merged
+    :type second_dict: dict
+    :return: merged dictionary
+    """
+    merged_dict = {}
+    if isinstance(first_dict, collections.defaultdict):
+        merged_dict = collections.defaultdict(first_dict.default_factory)
+
+    for item in first_dict:
+        if item in second_dict:
+            if isinstance(first_dict[item], dict):
+                merged_dict[item] = add_nested_dictionaries(
+                    first_dict[item], second_dict[item])
+            else:
+                merged_dict[item] = first_dict[item] + second_dict[item]
+        else:
+            merged_dict[item] = copy.deepcopy(first_dict[item])
+
+    for item in second_dict:
+        if item not in first_dict:
+            merged_dict[item] = copy.deepcopy(second_dict[item])
+
+    return merged_dict
\ No newline at end of file
