@@ -125,6 +125,27 @@ class TestAVRODataClass(unittest.TestCase):
                              data.length,
                              msg=input_file['path'])
 
+    def test_is_structured(self):
+        # Default construction
+        data = AVROData()
+        self.assertTrue(data.is_structured)
+
+        # With option specifying dataframe as data_format
+        data = AVROData(options={"data_format": "dataframe"})
+        self.assertTrue(data.is_structured)
+
+        # With option specifying flattened_dataframe as data_format
+        data = AVROData(options={"data_format": "flattened_dataframe"})
+        self.assertTrue(data.is_structured)
+
+        # With option specifying records as data_format
+        data = AVROData(options={"data_format": "records"})
+        self.assertFalse(data.is_structured)
+
+        # With option specifying json as data_format
+        data = AVROData(options={"data_format": "json"})
+        self.assertFalse(data.is_structured)
+
 
 if __name__ == '__main__':
     unittest.main()
