@@ -1,9 +1,9 @@
 from dataprofiler.profilers.profiler_options import CategoricalOptions
-from dataprofiler.tests.profilers.profiler_options.test_base_column_options \
-     import TestBaseColumnOptions
+from dataprofiler.tests.profilers.profiler_options.test_base_inspector_options \
+     import TestBaseInspectorOptions
 
 
-class TestCategoricalOptions(TestBaseColumnOptions):
+class TestCategoricalOptions(TestBaseInspectorOptions):
     
     option_class = CategoricalOptions
     
